==> haskell-attoparsec-iso8601-1.1.0.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.0.0
visibility:           public
id:                   attoparsec-iso8601-1.1.0.0-6QZ5bJhcCftDuqQvWEnPgo
key:                  attoparsec-iso8601-1.1.0.0-6QZ5bJhcCftDuqQvWEnPgo
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  e65b3c0af52ffc2c2969f5f2f057a30d
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.0.0-6QZ5bJhcCftDuqQvWEnPgo
depends:
    attoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM base-4.17.2.1
    base-compat-batteries-0.12.3-AamuJDxEOaGDSsek5bqLrT text-2.0.2
    time-1.12.2 time-compat-1.9.6.1-F4XAV5VAUT1HPiLZXnA3T4

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.1.0.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.0.0
visibility:           public
id:                   attoparsec-iso8601-1.1.0.0-51rt7tHCclUHOyzaNJwE6y
key:                  attoparsec-iso8601-1.1.0.0-51rt7tHCclUHOyzaNJwE6y
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  030ebc2371129e97e25114a3d5258bd7
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.0.0-51rt7tHCclUHOyzaNJwE6y
depends:
    attoparsec-0.14.4-HJXsa8cMY97Lp9qL0m21oG base-4.17.2.1
    base-compat-batteries-0.12.3-EJnG9Y6LxNUInDpbPixZvH text-2.0.2
    time-1.12.2 time-compat-1.9.6.1-4I1SulV73udEfSOYURXdEC

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
